#' @name Sushi_5C.bedpe
#' @title Sushi_5C.bedpe
#' @description This data set list the genomic locations of 5C interactions in multiple cell lines
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_5C.bedpe
#' @format bedpe format
#' @source Sanyal, A., Lajoie, B. R., Jain, G. & Dekker, J. The long-range interaction landscape of gene promoters. Nature 489, 109-113 (2012).
NULL

#' @name Sushi_ChIAPET_pol2.bedpe
#' @title Sushi_ChIAPET_pol2.bedpe
#' @description This data set list the genomic locations of Pol2 ChIA PET interactions in K562 cells
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_ChIAPET_pol2.bedpe
#' @format bedpe format
#' @source Li, G. et al. Extensive Promoter-Centered Chromatin Interactions Provide a Topological Basis for Transcription Regulation. Cell 148, 84-98 (2012).
NULL

#' @name Sushi_ChIPSeq_CTCF.bedgraph
#' @title Sushi_ChIPSeq_CTCF.bedgraph
#' @description This data set describes read depths across the genomce resulting from a  CTCF ChIP seq experiment in K562 cells
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_ChIPSeq_CTCF.bedgraph
#' @format bedgraph format
#' @source Consortium, T. E. P. An integrated encyclopedia of DNA elements in the human genome. Nature 489, 57-74 (2012).
NULL

#' @name Sushi_ChIPExo_CTCF.bedgraph
#' @title Sushi_ChIPExo_CTCF.bedgraph
#' @description This data set describes read depths across the genomce resulting from a  CTCF ChIP Exo experiment in K562 cells
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_ChIPExo_CTCF.bedgrap
#' @format bedgraph format
#' @source Rhee, H. S. & Pugh, B. F. Comprehensive genome-wide protein-DNA interactions detected at single-nucleotide resolution. Cell 147, 1408-1419 (2011).
NULL

#' @name Sushi_ChIPSeq_pol2.bedgraph
#' @title Sushi_ChIPSeq_pol2.bedgraph
#' @description This data set describes read depths across the genomce resulting from a  Pol2 ChIP seq experiment in K562 cells
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_ChIPSeq_pol2.bedgraph
#' @format bedgraph format
#' @source Consortium, T. E. P. An integrated encyclopedia of DNA elements in the human genome. Nature 489, 57-74 (2012).
NULL

#' @name Sushi_DNaseI.bedgraph
#' @title Sushi_DNaseI.bedgraph
#' @description This data set describes read depths across the genomce resulting from a  DNaseI hypersensitivity experiment in K562 cells
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_DNaseI.bedgraph
#' @format bedgraph format
#' @source Neph, S. et al. An expansive human regulatory lexicon encoded in transcription factor footprints. Nature 489, 83-90 (2012).
NULL

#' @name Sushi_ChIPSeq_pol2.bed
#' @title Sushi_ChIPSeq_pol2.bed
#' @description This data set describes aligned sequencing reads for Pol2 in K562 cells as determined by ChIP-seq
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_ChIPSeq_pol2.bed
#' @format bed format
#' @source Consortium, T. E. P. An integrated encyclopedia of DNA elements in the human genome. Nature 489, 57-74 (2012).
NULL


#' @name Sushi_ChIPSeq_severalfactors.bed
#' @title Sushi_ChIPSeq_severalfactors.bed
#' @description This data set describes binding sites for multiple factors in K562 cells as determined by ChIP-seq
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_ChIPSeq_severalfactors.bed
#' @format bed format
#' @source Consortium, T. E. P. An integrated encyclopedia of DNA elements in the human genome. Nature 489, 57-74 (2012).
NULL

#' @name Sushi_RNASeq_K562.bedgraph
#' @title Sushi_RNASeq_K562.bedgraph
#' @description Bedgraph data representing RNA-seq dat from K562
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_RNASeq_K562.bedgraph
#' @format bedgraph format
#' @source Consortium, T. E. P. An integrated encyclopedia of DNA elements in the human genome. Nature 489, 57-74 (2012).
NULL


#' @name Sushi_RNASeq_K562.bedgraph
#' @title Sushi_RNASeq_K562.bedgraph
#' @description Bedgraph data representing RNA-seq dat from K562
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_RNASeq_K562.bedgraph
#' @format bedgraph format
#' @source Consortium, T. E. P. An integrated encyclopedia of DNA elements in the human genome. Nature 489, 57-74 (2012).
NULL

#' @name Sushi_GWAS.bed
#' @title Sushi_GWAS.bed
#' @description Bed data representing results from a GWAS study of blood pressure and cardiovascular disease risk
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_GWAS.bed
#' @format bed format
#' @source Ehret, G. B. et al. Genetic variants in novel pathways influence blood pressure and cardiovascular disease risk. Nature 478, 103-109 (2011).
NULL

#' @name Sushi_HiC.matrix
#' @title Sushi_HiC.matrix
#' @description Bed data representing results from a GWAS study of blood pressure and cardiovascular disease risk
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_HiC.matrix
#' @format matrix
#' @source Dixon, J. R. et al. Topological domains in mammalian genomes identified by analysis of chromatin interactions. Nature (2012). doi:10.1038/nature11082
NULL

#' @name Sushi_genes.bed
#' @title Sushi_genes.bed
#' @description Bed data representing human genes
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_genes.bed
#' @format bed format
#' @source http://www.biomart.org/
NULL

#' @name Sushi_transcripts.bed
#' @title Sushi_transcripts.bed
#' @description Bed data representing human transcripts and their expression in K562 cells
#' with coordinates based on the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_transcripts.bed
#' @format bed format
#' @source http://www.biomart.org/ and Consortium, T. E. P. An integrated encyclopedia of DNA elements in the human genome. Nature 489, 57-74 (2012).
NULL

#' @name Sushi_hg18_genome
#' @title Sushi_hg18_genome
#' @description This data set describes the length of human chromosomes according to the NCBI36 / hg18 genome build.
#' @docType data
#' @usage Sushi_hg18_genome
#' @format two columns (column 1 = chromosome name, column 2 = length of chromosome)
#' @source http://www.biomart.org/ and Consortium, T. E. P. An integrated encyclopedia of DNA elements in the human genome. Nature 489, 57-74 (2012).
NULL







